library(sf) # Manipuler des données géographiques
library(ggplot2) # Réaliser des graphiques
library(dplyr) # Manipuler des données avec syntaxe tidyverse
library(stringr) #  Manipuler chaine de caractère
library(mapview) # Création (simple) de carte interactive (utilise leaflet)
library(lubridate) # Manipulation de date
library(RColorBrewer) # Gestion des couleurs
library(gganimate) # Création de graphiques ggplot animés
library(gifski) # Création de GIF
getwd()
setwd("C:/Users/hmathian/Desktop/ExploSHSAteliers/AtelierNettoyage/DATAParis")

## Import données géographiques
iris_Paris_sf <- st_read("ParisIris2017.shp", stringsAsFactors = FALSE)

# manque le code EPSG
st_crs(iris_Paris_sf)
st_crs(iris_Paris_sf) <- 2154 # SRID/EPSG du Lambert 93

# Affichage première lignes
head(iris_Paris_sf)


## Exploration/affichage géometries
# Avec fonction PLOT (Rbase)
plot(st_geometry(iris_Paris_sf))
plot(iris_Paris_sf["TYP_IRIS"])

# Avec fonction ggplot2
ggplot(iris_Paris_sf) +
  geom_sf()

# Avec mapview (carte interactive)
mapview(iris_Paris_sf)
mapview(iris_Paris_sf, zcol = "NOM_COM")


## Agrégations de données
# Par commune
arrond_Paris <- iris_Paris_sf %>%
                      group_by(INSEE_COM) %>%
                      summarise()

plot(st_geometry(arrond_Paris))


# Tout paris
tout_Paris <- mutate(iris_Paris_sf, Paris = "Paris") %>%
                  group_by(Paris) %>%
                  summarise()

plot(st_geometry(tout_Paris), col = "grey")


# Tout paris sans bois
tout_Parisssbois <- mutate(filter(iris_Paris_sf,!str_detect(NOM_IRIS, "Bois")),
                           Paris = "Paris") %>%
                                group_by(Paris) %>%
                                summarise()

plot(st_geometry(tout_Parisssbois),
     border = "red",
     add = TRUE)

# PAS ALPHA MAIS ALPHA.REGIONS !
mapview(tout_Paris, alpha = 0.5) +
  mapview(tout_Parisssbois, col.regions = "red", alpha.regions = 0.5)

# Import des données "dans ma rue"
df_dmr <- readRDS("dans_ma_rue_exploSHS.RDS")
head(df_dmr)

## ON EXPLORE
## De quoi ca parle ?
dmr_type <- df_dmr %>%
  count(TYPE)

#on élimine les anomalies bizarres
# Séléction en fonction du "type d'anomalie déclarée"
dmr <-  filter(df_dmr,!TYPE %in% c("Du vert près de chez moi", "Problème sur un chantier"))

# Création nouvelle colonnes à partir des modalité de la colone type
dmr <- dmr %>%
              mutate(
                TYPEp = case_when(
                  TYPE == "Arbres, végétaux et animaux" ~	"Vég./anim.",
                  TYPE == "Eau et assainissement" ~	"Eau",
                  TYPE == "Éclairage / Électricité"	~ "Ecl.Elec.",
                  TYPE == "Graffitis, tags, affiches et autocollants"	~ "Graff/Affiches",
                  TYPE == "Mobiliers urbains dégradés (arrachés, cassés, tordus, bancals, en panne... )" ~ 	"Mob.Urbain",
                  TYPE == "Objets abandonnés"	~ "Obj.abandon.",
                  TYPE == "Propreté"	~ "Propreté",
                  TYPE == "Voirie et déplacements" ~	"Voirie/Dépl"
                )
              )


# Solution Rbase 
dmr[dmr$TYPE == "Arbres, végétaux et animaux", "TYPEp"] <- "Vég./anim."
dmr[dmr$TYPE == "Eau et assainissement", "TYPEp"] <- "Eau"
dmr[dmr$TYPE == "Éclairage / Électricité", "TYPEp"] <- "Ecl.Elec."
dmr[dmr$TYPE == "Graffitis, tags, affiches et autocollants", "TYPEp"] <- "Graff/Affiches"
dmr[dmr$TYPE == "Mobiliers urbains dégradés (arrachés, cassés, tordus, bancals, en panne... )", "TYPEp"] <- "Mob.Urbain"
dmr[dmr$TYPE == "Objets abandonnés", "TYPEp"] <- "Obj.abandon."
dmr[dmr$TYPE == "Propreté", "TYPEp"] <- "Propreté"
dmr[dmr$TYPE == "Voirie et déplacements", "TYPEp"] <- "Voirie/Dépl"


# Agrégation par type
dmr_type <- dmr %>%
            count(TYPE, TYPEp)

dmr_type2 <- dmr %>%
             count(TYPEp, SOUSTYPE)


# QUAND ?
# Création colonnes date, autre unité)
dmr <- dmr %>%
            mutate(ANNEEDECL = year(DATEDECL)) %>%
            mutate(MOISDECL = month(DATEDECL, label = TRUE)) %>%
            mutate(JOURDECL = wday(DATEDECL, label = TRUE)) %>%
            mutate(HEUREDECL = hour(DATEDECL))

#ON EXPLORE LES TEMPORALITES
# Agrégation par année
dmr_an <- dmr %>%
            count(ANNEEDECL) %>%
            mutate(NBparAN = n * 100 / sum(n))

# Agrégation par mois de l'année
dmr_mois <- dmr %>%
              count(MOISDECL) %>%
              mutate(NBparAN = n * 100 / sum(n))

# Agrégation par jour de la semaine
dmr_jour <- dmr %>%
              count(JOURDECL) %>%
              mutate(NBparAN = n * 100 / sum(n))

# Agrégation par heure de la journée
dmr %>%
  count(HEUREDECL) %>%
  mutate(NBparAN = n * 100 / sum(n))


# Représentations graphiques 
ggplot(dmr, aes(x = ANNEEDECL)) +
  geom_bar()

ggplot(dmr, aes(x = MOISDECL, fill = as.factor(ANNEEDECL))) +
  geom_bar()

ggplot(dmr, aes(x = JOURDECL)) +
  geom_bar()

ggplot(dmr, aes(x = MOISDECL, fill = JOURDECL)) +
  geom_bar()

# Uniquement sur les données de 2017
dmr %>% 
  filter(ANNEEDECL == 2017) %>% 
  ggplot(aes(x = MOISDECL, fill = JOURDECL)) +
  geom_bar()


## OU ?
# transformation des donnèes de 2015 en donnèes géographiques
# A partir des des variables "Long" et "Lat"
dmr_sf2015 <- dmr %>%
                filter(ANNEEDECL %in% c(2015)) %>%
                st_as_sf(coords = c("Long", "Lat"), crs = 4326) %>%
                st_transform(2154) # Pour une opération géométrique, les objets doivent avoir le même SRID

# Cartographie données 2015
plot(st_geometry(tout_Parisssbois), col = "grey")
plot(st_geometry(dmr_sf2015),
      col = "red",
      pch = 20,
      add = TRUE)

# Séléction des données par localisation - Dans Paris uniquement
dmrsf_2015 <- filter(dmr_sf2015, st_within(dmr_sf2015, tout_Parisssbois, sparse = FALSE))


# Assignation de couleurs aux Types
library(RColorBrewer)
display.brewer.all()
display.brewer.pal(n = 8, name = "Set1")
cols <- brewer.pal(n = 8, name = "Set1")
cols
names(cols) <- unique(dmrsf_2015$TYPEp) #on assigne un des types à une couleur
cols


# Carte
plot(st_geometry(tout_Parisssbois), col = "grey")
plot(st_geometry(dmrsf_2015),
     col = cols,
     pch = 20,
     add = TRUE) # les beaux smarties

# Carte interactive
mapview(dmrsf_2015, 
        zcol = "TYPEp", 
        col.regions = cols, 
        burst = TRUE) # demo usage de la couche


# spatio-temporel 
#On construit la distribution par TYPE et Jour de la semaine
# spatio-temporel (CORRECTION et code plus compréhensible)
dmrsf_2015_TypeJ <- st_set_geometry(dmrsf_2015,NULL) %>%
  group_by(TYPEp, JOURDECL) %>%
  summarise(countJ = n()) %>% 
  ungroup()

TEMP_sum <- st_set_geometry(dmrsf_2015,NULL) %>%
  group_by(TYPEp) %>%
  summarise(count = n())%>% 
  ungroup()


dmrsf_2015_TypeJ <- left_join(dmrsf_2015_TypeJ, 
                         TEMP_sum,
                         by="TYPEp") %>% 
  mutate(perc=countJ*100/count)


#IDEM en un coup!
dmrsf_2015_TypeJ <- st_set_geometry(dmrsf_2015, NULL) %>% #on enlève le champ géométrique
                            group_by(TYPEp, JOURDECL) %>%
                                summarise(countJ = n()) %>%
                                left_join(st_set_geometry(dmr_sf2015, NULL) %>%
                                group_by(TYPEp) %>%
                                summarise(count = n()),by = "TYPEp") %>%
                                mutate(perc = countJ * 100 / count) %>%
                                ungroup()



# Visualisation graphique
ggplot(dmrsf_2015_TypeJ, aes(x = JOURDECL, y = perc, fill = JOURDECL)) +
  geom_bar(stat = "identity") +
  facet_grid(. ~ TYPEp)


# Séléction par typep
dmr_graff <- dmr_sf2015 %>%
                filter(TYPEp %in% c("Graff/Affiches", "Mob.Urbain"))



# Séléction Dimanche janvier 2015
DimJanv2015 <- filter(dmrsf_2015, MOISDECL == "janv" & JOURDECL == "dim\\.") 

# Jointure avec table des couleurs
colors <- data.frame(cols,names(cols))
DimJanv2015 <- merge(DimJanv2015, 
                     colors, by.x="TYPEp",by.y="names.cols.")

# visu
ggplot(DimJanv2015) +
  geom_sf(aes(col = TYPEp), size = 2, shape = 20) +
  scale_fill_manual(values = colors) 


# animate NE MARCHE PAS

# Installation gifski forcée pour moi
# remotes::install_github("r-rust/gifski")

library(remotes)

library(gifski)
install.packages("transformr")
library(transformr)

# Preparation basemap
mapParis <- ggplot(tout_Parisssbois) +
  geom_sf(colour = "gray85", fill = "gray80")

# Animation
  mapParis +
  geom_sf(data=DimJanv2015, aes(col = TYPEp), size = 2, shape = 20) +
  transition_states(TYPEp, transition_length = 2, state_length = 2)

#ON REGARDE  CE QU'IL EN EST AU NIVEAU IRIS

#Jointure spatiale pour incident DANS IRIS
dmrsf_2015 <- dmrsf_2015 %>%
      st_join(iris_Paris_sf %>% select(CODE_IRIS), join = st_within)

# Solution 2, sans pipe ;-) 
dmrsf_2015 <- st_join(dmrsf_2015, iris_Paris_sf["CODE_IRIS"],  join = st_within)


# Jointure et aggrégation
# Dur dur ce bout de code sans décomposer...

iris_nb2015 <- iris_Paris_sf %>%
                  left_join(
                    st_set_geometry(dmrsf_2015, NULL) %>%
                  group_by(CODE_IRIS) %>%
      summarise(NbIncidents = n()) %>%
      ungroup(),
    by = "CODE_IRIS")
iris_nb2015 <- iris_nb2015 %>%
  mutate(DensIncidents = NbIncidents / (st_area(.) / 1E6)) %>%  #pour avoir densité km2
  mutate(DensIncidents = units::drop_units(DensIncidents))


# Visu
mapview(iris_nb2015, zcol = "DensIncidents", legend = TRUE)


#----------------
